EnumDropdownEditor<T> class
Constructors
-
EnumDropdownEditor({required LabelBuilder<
T> labelBuilder, required List<T> values}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labelBuilder
→ LabelBuilder<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
T> -
final
Methods
-
accept<
R> (ParamEditorFactory< R> v) → R -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited